@@ -12,7 +12,7 @@ urlpatterns = [
 
     # code login
     path('code', views.LoginView.as_view(), name='code_login'),
-    path('code/', RedirectView.as_view(pattern_name='code_login')),
+    path('code/', RedirectView.as_view(pattern_name='vote:code_login')),
     path('code/<str:access_code>', views.code_login, name='link_login'),
     path('logout', auth_views.LogoutView.as_view(
         next_page='vote:index',
@@ -20,5 +20,5 @@ urlpatterns = [
     path('vote/<int:election_id>/apply', views.apply, name='apply'),
     path('vote/<int:election_id>/delete-own-application', views.delete_own_application, name='delete_own_application'),
     path('help', views.help_page, name='help'),
-    path('spectator/<str:uuid>', views.spectator, name='spectator')
+    path('spectator/<uuid:uuid>', views.spectator, name='spectator')
 ]
